@@ -22,6 +22,7 @@ from suite_py.commands.project_lock import ProjectLock
 from suite_py.commands.status import Status
 from suite_py.commands.aggregator import Aggregator
 from suite_py.commands.secret import Secret
+from suite_py.commands.login import Login
 from suite_py.lib.config import Config
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
@@ -200,6 +201,12 @@ def cli_aggregator(obj, show_list, change):
     Aggregator(obj["config"], show_list, change).run()
 
 
+@main.command("login", help="manage login against Auth0")
+@click.pass_obj
+def login(obj):
+    Login(obj["config"]).run()
+
+
 @main.command(
     "secret", help="Manage secrets grants in multiple countries (aws-vault needed)"
 )
